django-master
=============

Master dashboard for django

[![Build Status](https://travis-ci.org/andrefarzat/django-master.svg?branch=master)](https://travis-ci.org/andrefarzat/django-master)
[![Coverage Status](https://coveralls.io/repos/andrefarzat/django-master/badge.png?branch=master)](https://coveralls.io/r/andrefarzat/django-master?branch=master)
[![Requirements Status](https://requires.io/github/andrefarzat/django-master/requirements.png?branch=master)](https://requires.io/github/andrefarzat/django-master/requirements/?branch=master)

ROADMAP 0.1.0
-------------

* [x] The router list
* [x] The settings list

ROADMAP 0.2.0
-------------

* [x] Nice interface

ROADMAP 0.3.0
-------------

* [x] pylint report in all .py files
* [x] Jshint report in all .js files


ROADMAP 0.4.0
-------------
* [ ] Execute django tests in the browser


ROADMAP 0.5.0
-------------
* [ ] Model reference in the browser

ROADMAP 0.6.0
-------------
* [ ] Integrate GIT log of the current project

